@@ -17,26 +17,29 @@
 
 package org.apache.inlong.agent.message;
 
+import static org.apache.inlong.agent.constants.CommonConstants.PROXY_KEY_GROUP_ID;
+import static org.apache.inlong.agent.constants.CommonConstants.PROXY_KEY_STREAM_ID;
+
 import java.util.Map;
 import org.apache.inlong.agent.plugin.Message;
 
 /**
- * Bus message with body, header, bid and tid.
+ * Bus message with body, header, inlongGroupId and inlongStreamId.
  */
 public class ProxyMessage implements Message {
 
-    private static final String DEFAULT_TID = "__";
+    private static final String DEFAULT_INLONG_STREAM_ID = "__";
 
     private final byte[] body;
     private final Map<String, String> header;
-    private final String bid;
-    private final String tid;
+    private final String inlongGroupId;
+    private final String inlongStreamId;
 
     public ProxyMessage(byte[] body, Map<String, String> header) {
         this.body = body;
         this.header = header;
-        this.bid = header.get("bid");
-        this.tid = header.getOrDefault("tid", DEFAULT_TID);
+        this.inlongGroupId = header.get(PROXY_KEY_GROUP_ID);
+        this.inlongStreamId = header.getOrDefault(PROXY_KEY_STREAM_ID, DEFAULT_INLONG_STREAM_ID);
     }
 
     /**
@@ -59,12 +62,12 @@ public class ProxyMessage implements Message {
         return header;
     }
 
-    public String getBid() {
-        return bid;
+    public String getInlongGroupId() {
+        return inlongGroupId;
     }
 
-    public String getTid() {
-        return tid;
+    public String getInlongStreamId() {
+        return inlongStreamId;
     }
 
     public static ProxyMessage parse(Message message) {
