@@ -45,14 +45,21 @@ import java.util.List;
 import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.LinkedBlockingQueue;
 import java.util.concurrent.TimeUnit;
+import java.util.concurrent.atomic.AtomicLong;
 import org.apache.inlong.agent.common.AbstractDaemon;
 import org.apache.inlong.agent.conf.JobProfile;
 import org.apache.inlong.agent.plugin.Message;
 import org.apache.inlong.agent.plugin.MessageFilter;
 import org.apache.inlong.agent.plugin.Sink;
+import org.apache.inlong.agent.plugin.metrics.PluginJmxMetric;
 import org.apache.inlong.agent.plugin.metrics.PluginMetric;
+import org.apache.inlong.agent.plugin.metrics.PluginPrometheusMetric;
+import org.apache.inlong.agent.plugin.metrics.SinkJmxMetric;
+import org.apache.inlong.agent.plugin.metrics.SinkMetrics;
+import org.apache.inlong.agent.plugin.metrics.SinkPrometheusMetrics;
 import org.apache.inlong.agent.plugin.utils.PluginUtils;
 import org.apache.inlong.agent.utils.AgentUtils;
+import org.apache.inlong.agent.utils.ConfigUtil;
 import org.apache.pulsar.client.api.CompressionType;
 import org.apache.pulsar.client.api.MessageId;
 import org.apache.pulsar.client.api.Producer;
@@ -63,6 +70,9 @@ import org.slf4j.LoggerFactory;
 
 public class PulsarSink extends AbstractDaemon implements Sink {
     private static final Logger LOGGER = LoggerFactory.getLogger(PulsarSink.class);
+
+    private static final String PULSAR_SINK_TAG_NAME = "AgentPulsarMetric";
+
     private boolean async;
     private long pollTimeout;
     private int threadNum;
@@ -72,8 +82,24 @@ public class PulsarSink extends AbstractDaemon implements Sink {
     private LinkedBlockingQueue<byte[]> cache;
     private final List<Producer<byte[]>> producerList = new ArrayList<>();
 
-    private final PluginMetric metric = new PluginMetric();
+    private final PluginMetric pluginMetricNew;
+    private final SinkMetrics sinkMetrics;
     private PulsarClient client;
+    private static AtomicLong metricsIndex = new AtomicLong(0);
+
+    public PulsarSink() {
+        if (ConfigUtil.isPrometheusEnabled()) {
+            this.pluginMetricNew = new PluginPrometheusMetric(AgentUtils.getUniqId(
+                PULSAR_SINK_TAG_NAME, metricsIndex.incrementAndGet()));
+            this.sinkMetrics = new SinkPrometheusMetrics(AgentUtils.getUniqId(
+                PULSAR_SINK_TAG_NAME, metricsIndex.incrementAndGet()));
+        } else {
+            this.pluginMetricNew = new PluginJmxMetric(AgentUtils.getUniqId(
+                PULSAR_SINK_TAG_NAME, metricsIndex.incrementAndGet()));
+            this.sinkMetrics = new SinkJmxMetric(AgentUtils.getUniqId(
+                PULSAR_SINK_TAG_NAME, metricsIndex.incrementAndGet()));
+        }
+    }
 
     @Override
     public void write(Message message) {
@@ -81,10 +107,14 @@ public class PulsarSink extends AbstractDaemon implements Sink {
             // if message is not null
             try {
                 // put message to cache, wait until cache is not full.
-                metric.sendNum.incr();
+                pluginMetricNew.incSendNum();
                 cache.put(message.getBody());
+                // increment the count of successful sinks
+                sinkMetrics.incSinkSuccessCount();
             } catch (Exception ignored) {
                 // ignore it
+                // increment the count of failed sinks
+                sinkMetrics.incSinkFailCount();
             }
         }
     }
@@ -116,7 +146,7 @@ public class PulsarSink extends AbstractDaemon implements Sink {
         try {
             stop();
             LOGGER.info("send success num is {}, failed num is {}",
-                metric.sendSuccessNum.snapshot(), metric.sendFailedNum.snapshot());
+                pluginMetricNew.getSendSuccessNum(), pluginMetricNew.getSendFailedNum());
         } catch (Exception ex) {
             LOGGER.error("exception caught", ex);
         }
@@ -136,12 +166,12 @@ public class PulsarSink extends AbstractDaemon implements Sink {
                 // exception is not null, that means not success.
                 // TODO: add metric or retry sending message.
                 if (t != null) {
-                    metric.sendFailedNum.incr();
+                    pluginMetricNew.incSendFailedNum();
                     if (!cache.offer(item)) {
                         LOGGER.warn("message {} not add back to retry", m);
                     }
                 } else {
-                    metric.sendSuccessNum.incr();
+                    pluginMetricNew.incSendSuccessNum();
                 }
             });
         } else {
