@@ -38,8 +38,8 @@ public class TDMsg1 {
     private static final int BIN_MSG_SNAPPY_TYPE = 1;
 
     private static final int BIN_MSG_TOTALLEN_OFFSET = 0;
-    private static final int BIN_MSG_BID_OFFSET = 5;
-    private static final int BIN_MSG_TID_OFFSET = 7;
+    private static final int BIN_MSG_GROUPID_OFFSET = 5;
+    private static final int BIN_MSG_STREAMID_OFFSET = 7;
     private static final int BIN_MSG_EXTFIELD_OFFSET = 9;
     private static final int BIN_MSG_COUNT_OFFSET = 15;
     private static final int BIN_MSG_DATATIME_OFFSET = 11;
@@ -96,7 +96,7 @@ public class TDMsg1 {
     private int datalen = 0;
     private int msgcnt = 0;
     private boolean compress;
-    private boolean isNumBid = false;
+    private boolean isNumGroupId = false;
     private boolean ischeck = true;
 
     private final Version version;
@@ -261,7 +261,6 @@ public class TDMsg1 {
         return addMsg(attr, ByteBuffer.wrap(data));
     }
 
-    /* 新增支持新数据消息 */
     public boolean addMsg(byte[] data) {
         return addMsg(ByteBuffer.wrap(data));
     }
@@ -300,7 +299,6 @@ public class TDMsg1 {
     }
 
     private boolean checkBinData(ByteBuffer data) {
-        // 检查消息合法性
         int totalLen = data.getInt(BIN_MSG_TOTALLEN_OFFSET);
         int bodyLen = data.getInt(BIN_MSG_BODYLEN_OFFSET);
         int attrLen = data.getShort(BIN_MSG_BODY_OFFSET + bodyLen);
@@ -636,7 +634,7 @@ public class TDMsg1 {
             parsedBinInput = ByteBuffer.wrap(binMsg);
             this.createtime = getBinCreatetime(parsedBinInput);
             this.msgcnt = getBinMsgCnt(parsedBinInput);
-            this.isNumBid = getBinNumFlag(parsedBinInput);
+            this.isNumGroupId = getBinNumFlag(parsedBinInput);
         }
     }
 
@@ -682,7 +680,7 @@ public class TDMsg1 {
             parsedInput.skip(len - 1);
 
             while (bodyBuffer.remaining() > 0) {
-                // total message length = （data length + attributes length) * N
+                // total message length = (data length + attributes length) * N
                 int singleTotalLen = bodyBuffer.getInt();
                 if (singleTotalLen > bodyBuffer.remaining()) {
                     return;
@@ -738,8 +736,8 @@ public class TDMsg1 {
 
         int totalLen = parsedBinInput.getInt(BIN_MSG_TOTALLEN_OFFSET);
         final int msgtype = parsedBinInput.get(BIN_MSG_MSGTYPE_OFFSET);
-        int bidNum = parsedBinInput.getShort(BIN_MSG_BID_OFFSET);
-        int tidNum = parsedBinInput.getShort(BIN_MSG_TID_OFFSET);
+        int groupIdNum = parsedBinInput.getShort(BIN_MSG_GROUPID_OFFSET);
+        int streamIdNum = parsedBinInput.getShort(BIN_MSG_STREAMID_OFFSET);
         int bodyLen = parsedBinInput.getInt(BIN_MSG_BODYLEN_OFFSET);
         long dataTime = parsedBinInput.getInt(BIN_MSG_DATATIME_OFFSET);
         final int extField = parsedBinInput.getShort(BIN_MSG_EXTFIELD_OFFSET);
@@ -785,11 +783,11 @@ public class TDMsg1 {
                 break;
         }
 
-        //number bid/tid
-        boolean isUseNumBid = ((extField & 0x4) == 0x0);
-        if (isUseNumBid) {
-            commonAttrMap.put(AttributeConstants.BUSINESS_ID, String.valueOf(bidNum));
-            commonAttrMap.put(AttributeConstants.INTERFACE_ID, String.valueOf(tidNum));
+        //number groupId/streamId
+        boolean isUseNumGroupId = ((extField & 0x4) == 0x0);
+        if (isUseNumGroupId) {
+            commonAttrMap.put(AttributeConstants.GROUP_ID, String.valueOf(groupIdNum));
+            commonAttrMap.put(AttributeConstants.INTERFACE_ID, String.valueOf(streamIdNum));
         }
 
         boolean hasOtherAttr = ((extField & 0x1) == 0x1);
@@ -1101,8 +1099,8 @@ public class TDMsg1 {
         return attrcnt;
     }
 
-    public boolean isNumBid() {
+    public boolean isNumGroupId() {
         checkMode(false);
-        return isNumBid;
+        return isNumGroupId;
     }
 }
