@@ -28,7 +28,7 @@ public interface MessageSender {
 
     /**
      * This method provides a synchronized function which you want to send data
-     * with extra attributes except  bid,tid,dt,etc
+     * with extra attributes except  groupId,streamId,dt,etc
      * This method is deprecated,we suggest you don't use it.
      *
      * @param body       The data will be sent
@@ -44,19 +44,19 @@ public interface MessageSender {
      * @param body The data will be sent
      *             
      */
-    public SendResult sendMessage(byte[] body, String bid, String tid, long dt, String msgUUID,
+    public SendResult sendMessage(byte[] body, String groupId, String streamId, long dt, String msgUUID,
                                   long timeout, TimeUnit timeUnit);
 
     /**
      * This method provides a synchronized  function which you want to send data without packing
-     * with extra attributes except  bid,tid,dt,etc
+     * with extra attributes except  groupId,streamId,dt,etc
      *
      * @param body         The data will be sent
      *                     
      * @param extraAttrMap The attributes you want to add,
      *                     and each element of extraAttrMap contains a pair like <attrKey,attrValue>
      */
-    public SendResult sendMessage(byte[] body, String bid, String tid, long dt, String msgUUID,
+    public SendResult sendMessage(byte[] body, String groupId, String streamId, long dt, String msgUUID,
                                   long timeout, TimeUnit timeUnit, Map<String, String> extraAttrMap);
 
     /**
@@ -65,24 +65,24 @@ public interface MessageSender {
      *
      * @param bodyList The data will be sent,which is a collection consisting of byte arrays
      */
-    public SendResult sendMessage(List<byte[]> bodyList, String bid, String tid, long dt, String msgUUID,
+    public SendResult sendMessage(List<byte[]> bodyList, String groupId, String streamId, long dt, String msgUUID,
                                   long timeout, TimeUnit timeUnit);
 
     /**
      * This method provides a synchronized  function which you want to send data with packing
-     * with extra attributes except  bid,tid,dt,etc
+     * with extra attributes except  groupId,streamId,dt,etc
      * 
      *
      * @param bodyList     The data will be sent,which is a collection consisting of byte arrays
      * @param extraAttrMap The attributes you want to add,
      *                     and each element of extraAttrMap contains a pair like <attrKey,attrValue>
      */
-    public SendResult sendMessage(List<byte[]> bodyList, String bid, String tid, long dt, String msgUUID,
+    public SendResult sendMessage(List<byte[]> bodyList, String groupId, String streamId, long dt, String msgUUID,
                                   long timeout, TimeUnit timeUnit, Map<String, String> extraAttrMap);
 
     /**
      * This method provides an asynchronized  function which you want to send data
-     * with extra attributes except  bid,tid,dt,etc
+     * with extra attributes except  groupId,streamId,dt,etc
      * This method is deprecated,we suggest you don't use it.
      * 
      *
@@ -96,7 +96,7 @@ public interface MessageSender {
 
     /**
      * This method provides a synchronized  function which you want to send data without packing
-     * with extra attributes except  bid,tid,dt,etc
+     * with extra attributes except  groupId,streamId,dt,etc
      * 
      *
      * @param body         The data will be sent
@@ -104,7 +104,7 @@ public interface MessageSender {
      *                     and each element of extraAttrMap contains a pair like <attrKey,attrValue>
      */
     public void asyncSendMessage(SendMessageCallback callback,
-                                 byte[] body, String bid, String tid, long dt, String msgUUID,
+                                 byte[] body, String groupId, String streamId, long dt, String msgUUID,
                                  long timeout, TimeUnit timeUnit,
                                  Map<String, String> extraAttrMap) throws ProxysdkException;
 
@@ -116,7 +116,7 @@ public interface MessageSender {
      * @param body     The data will be sent
      */
     public void asyncSendMessage(SendMessageCallback callback,
-                                 byte[] body, String bid, String tid, long dt, String msgUUID,
+                                 byte[] body, String groupId, String streamId, long dt, String msgUUID,
                                  long timeout, TimeUnit timeUnit) throws ProxysdkException;
 
     /**
@@ -126,12 +126,12 @@ public interface MessageSender {
      * @param bodyList The data will be sent,which is a collection consisting of byte arrays
      */
     public void asyncSendMessage(SendMessageCallback callback,
-                                 List<byte[]> bodyList, String bid, String tid, long dt, String msgUUID,
+                                 List<byte[]> bodyList, String groupId, String streamId, long dt, String msgUUID,
                                  long timeout, TimeUnit timeUnit) throws ProxysdkException;
 
     /**
      * This method provides an asynchronized  function which you want to send data with packing
-     * with extra attributes except  bid,tid,dt,etc
+     * with extra attributes except  groupId,streamId,dt,etc
      * 
      *
      * @param bodyList     The data will be sent,which is a collection consisting of byte arrays
@@ -139,7 +139,7 @@ public interface MessageSender {
      *                     element of extraAttrMap contains a pair like <attrKey,attrValue>
      */
     public void asyncSendMessage(SendMessageCallback callback,
-                                 List<byte[]> bodyList, String bid, String tid, long dt, String msgUUID,
+                                 List<byte[]> bodyList, String groupId, String streamId, long dt, String msgUUID,
                                  long timeout, TimeUnit timeUnit,
                                  Map<String, String> extraAttrMap) throws ProxysdkException;
 
