@@ -35,7 +35,7 @@ public class ProxyUtils {
     private static final Set<String> invalidAttr = new HashSet<>();
 
     static {
-        Collections.addAll(invalidAttr, "bid", "tid", "dt", "msgUUID", "cp",
+        Collections.addAll(invalidAttr, "groupId", "streamId", "dt", "msgUUID", "cp",
             "cnt", "mt", "m", "sid", "t", "NodeIP", "messageId", "_file_status_check", "_secretId",
             "_signature", "_timeStamp", "_nonce", "_userName", "_clientIP", "_encyVersion", "_encyDesKey");
     }
