@@ -38,12 +38,14 @@ public interface BusinessEntityMapper {
 
     List<Map<String, Object>> countCurrentUserBusiness(@Param(value = "currentUser") String currentUser);
 
-    BusinessEntity selectByIdentifier(String businessIdentifier);
+    BusinessEntity selectByIdentifier(String groupId);
 
-    Integer selectIdentifierExist(String businessIdentifier);
+    Integer selectIdentifierExist(String groupId);
 
     List<BusinessEntity> selectByCondition(BusinessPageRequest request);
 
+    List<BusinessEntity> selectAll(Integer status);
+
     /**
      * get all config with business status of 130, that is, config successful
      */
@@ -55,7 +57,7 @@ public interface BusinessEntityMapper {
 
     int updateByPrimaryKey(BusinessEntity record);
 
-    int updateStatusByIdentifier(@Param("bid") String bid, @Param("status") Integer status,
+    int updateStatusByIdentifier(@Param("groupId") String groupId, @Param("status") Integer status,
             @Param("modifier") String modifier);
 
 }
\ No newline at end of file
