@@ -37,13 +37,16 @@ import org.apache.inlong.manager.common.pojo.business.BusinessExtInfo;
 import org.apache.inlong.manager.common.pojo.business.BusinessInfo;
 import org.apache.inlong.manager.common.pojo.business.BusinessListVO;
 import org.apache.inlong.manager.common.pojo.business.BusinessPageRequest;
+import org.apache.inlong.manager.common.pojo.business.BusinessPulsarInfo;
 import org.apache.inlong.manager.common.pojo.business.BusinessTopicVO;
 import org.apache.inlong.manager.common.util.CommonBeanUtils;
 import org.apache.inlong.manager.common.util.Preconditions;
 import org.apache.inlong.manager.dao.entity.BusinessEntity;
 import org.apache.inlong.manager.dao.entity.BusinessExtEntity;
+import org.apache.inlong.manager.dao.entity.BusinessPulsarEntity;
 import org.apache.inlong.manager.dao.mapper.BusinessEntityMapper;
 import org.apache.inlong.manager.dao.mapper.BusinessExtEntityMapper;
+import org.apache.inlong.manager.dao.mapper.BusinessPulsarEntityMapper;
 import org.apache.inlong.manager.service.core.BusinessService;
 import org.apache.inlong.manager.service.core.DataStreamService;
 import org.slf4j.Logger;
@@ -59,7 +62,8 @@ import org.springframework.transaction.annotation.Transactional;
 public class BusinessServiceImpl implements BusinessService {
 
     private static final Logger LOGGER = LoggerFactory.getLogger(BusinessServiceImpl.class);
-
+    @Autowired
+    BusinessPulsarEntityMapper businessPulsarMapper;
     @Autowired
     private BusinessEntityMapper businessMapper;
     @Autowired
@@ -77,54 +81,105 @@ public class BusinessServiceImpl implements BusinessService {
         String bizName = businessInfo.getName();
         Preconditions.checkNotNull(bizName, "business name is empty");
 
-        String topic = bizName.toLowerCase(Locale.ROOT);
-        // bid=b_topic, cannot update
-        String bid = "b_" + topic;
-        Integer count = businessMapper.selectIdentifierExist(bid);
+        // groupId=b_bizName, cannot update
+        String groupId = "b_" + bizName.toLowerCase(Locale.ROOT);
+        Integer count = businessMapper.selectIdentifierExist(groupId);
         if (count >= 1) {
-            LOGGER.error("bid [{}] has already exists", bid);
+            LOGGER.error("groupId [{}] has already exists", groupId);
             throw new BusinessException(BizErrorCodeEnum.BUSINESS_DUPLICATE);
         }
 
         // Processing business and extended information
         BusinessEntity entity = CommonBeanUtils.copyProperties(businessInfo, BusinessEntity::new);
-        entity.setBusinessIdentifier(bid);
-        entity.setMqResourceObj(topic);
+        entity.setInlongGroupId(groupId);
+        entity.setMqResourceObj(groupId);
 
         // Only M0 is currently supported
         entity.setSchemaName(BizConstant.SCHEMA_M0_DAY);
 
         // After saving, the status is set to [BIZ_WAIT_SUBMIT]
         entity.setStatus(EntityStatus.BIZ_WAIT_SUBMIT.getCode());
-
+        entity.setIsDeleted(EntityStatus.UN_DELETED.getCode());
         entity.setCreator(operator);
         entity.setModifier(operator);
         entity.setCreateTime(new Date());
         businessMapper.insertSelective(entity);
+        this.saveExt(groupId, businessInfo.getExtList());
 
-        this.saveExt(bid, businessInfo.getExtList());
+        if (BizConstant.MIDDLEWARE_PULSAR.equals(businessInfo.getMiddlewareType())) {
+            BusinessPulsarInfo pulsarInfo = (BusinessPulsarInfo) businessInfo.getMqExtInfo();
+            Preconditions.checkNotNull(pulsarInfo, "Pulsar info cannot be empty, as the middleware is Pulsar");
 
-        LOGGER.info("success to save business info");
-        return bid;
+            // Pulsar params must meet: ackQuorum <= writeQuorum <= ensemble
+            Integer ackQuorum = pulsarInfo.getAckQuorum();
+            Integer writeQuorum = pulsarInfo.getWriteQuorum();
+
+            Preconditions.checkNotNull(ackQuorum, "Pulsar ackQuorum cannot be empty");
+            Preconditions.checkNotNull(writeQuorum, "Pulsar writeQuorum cannot be empty");
+
+            if (!(ackQuorum <= writeQuorum)) {
+                throw new BusinessException(BizErrorCodeEnum.BUSINESS_SAVE_FAILED,
+                        "Pulsar params must meet: ackQuorum <= writeQuorum");
+            }
+            // The default value of ensemble is writeQuorum
+            pulsarInfo.setEnsemble(writeQuorum);
+
+            // Pulsar entity may already exist, such as unsuccessfully deleted, or modify the business MQ type to Tube,
+            // need to delete and add the Pulsar entity with the same group id
+            BusinessPulsarEntity pulsarEntity = businessPulsarMapper.selectByGroupId(groupId);
+            if (pulsarEntity == null) {
+                pulsarEntity = CommonBeanUtils.copyProperties(pulsarInfo, BusinessPulsarEntity::new);
+                pulsarEntity.setIsDeleted(0);
+                pulsarEntity.setInlongGroupId(groupId);
+                businessPulsarMapper.insertSelective(pulsarEntity);
+            } else {
+                Integer id = pulsarEntity.getId();
+                pulsarEntity = CommonBeanUtils.copyProperties(pulsarInfo, BusinessPulsarEntity::new);
+                pulsarEntity.setId(id);
+                businessPulsarMapper.updateByPrimaryKeySelective(pulsarEntity);
+            }
+        }
+
+        LOGGER.info("success to save business info for groupId={}", groupId);
+        return groupId;
     }
 
     @Override
-    public BusinessInfo get(String identifier) {
-        LOGGER.debug("begin to get business info by bid={}", identifier);
-        Preconditions.checkNotNull(identifier, BizConstant.BID_IS_EMPTY);
-        BusinessEntity entity = businessMapper.selectByIdentifier(identifier);
+    public BusinessInfo get(String groupId) {
+        LOGGER.debug("begin to get business info by groupId={}", groupId);
+        Preconditions.checkNotNull(groupId, BizConstant.GROUP_ID_IS_EMPTY);
+        BusinessEntity entity = businessMapper.selectByIdentifier(groupId);
         if (entity == null) {
-            LOGGER.error("business not found by bid={}", identifier);
+            LOGGER.error("business not found by groupId={}", groupId);
             throw new BusinessException(BizErrorCodeEnum.BUSINESS_NOT_FOUND);
         }
 
         BusinessInfo businessInfo = CommonBeanUtils.copyProperties(entity, BusinessInfo::new);
-        List<BusinessExtEntity> extEntityList = businessExtMapper.selectByBusinessIdentifier(identifier);
+        List<BusinessExtEntity> extEntityList = businessExtMapper.selectByGroupId(groupId);
         List<BusinessExtInfo> extInfoList = CommonBeanUtils
                 .copyListProperties(extEntityList, BusinessExtInfo::new);
         businessInfo.setExtList(extInfoList);
 
-        LOGGER.info("success to get business info");
+        // If the middleware is Pulsar, we need to encapsulate Pulsar related data
+        String middlewareType = entity.getMiddlewareType();
+        if (BizConstant.MIDDLEWARE_PULSAR.equalsIgnoreCase(middlewareType)) {
+            BusinessPulsarEntity pulsarEntity = businessPulsarMapper.selectByGroupId(groupId);
+            Preconditions.checkNotNull(pulsarEntity, "Pulsar info not found for the Pulsar business");
+            BusinessPulsarInfo pulsarInfo = CommonBeanUtils.copyProperties(pulsarEntity, BusinessPulsarInfo::new);
+            businessInfo.setMqExtInfo(pulsarInfo);
+        }
+
+        // For approved business, encapsulate the cluster address of the middleware
+        if (EntityStatus.BIZ_CONFIG_SUCCESSFUL.getCode().equals(businessInfo.getStatus())) {
+            if (BizConstant.MIDDLEWARE_TUBE.equalsIgnoreCase(middlewareType)) {
+                businessInfo.setTubeMaster(clusterBean.getTubeMaster());
+            } else if (BizConstant.MIDDLEWARE_PULSAR.equalsIgnoreCase(middlewareType)) {
+                businessInfo.setPulsarAdminUrl(clusterBean.getPulsarAdminUrl());
+                businessInfo.setPulsarServiceUrl(clusterBean.getPulsarServiceUrl());
+            }
+        }
+
+        LOGGER.info("success to get business info for groupId={}", groupId);
         return businessInfo;
     }
 
@@ -148,12 +203,12 @@ public class BusinessServiceImpl implements BusinessService {
     public String update(BusinessInfo businessInfo, String operator) {
         LOGGER.debug("begin to update business info={}", businessInfo);
         Preconditions.checkNotNull(businessInfo, "business info is empty");
-        String bid = businessInfo.getBusinessIdentifier();
-        Preconditions.checkNotNull(bid, BizConstant.BID_IS_EMPTY);
+        String groupId = businessInfo.getInlongGroupId();
+        Preconditions.checkNotNull(groupId, BizConstant.GROUP_ID_IS_EMPTY);
 
-        BusinessEntity entity = businessMapper.selectByIdentifier(bid);
+        BusinessEntity entity = businessMapper.selectByIdentifier(groupId);
         if (entity == null) {
-            LOGGER.error("business not found by bid={}", bid);
+            LOGGER.error("business not found by groupId={}", groupId);
             throw new BusinessException(BizErrorCodeEnum.BUSINESS_NOT_FOUND);
         }
 
@@ -168,10 +223,25 @@ public class BusinessServiceImpl implements BusinessService {
         businessMapper.updateByIdentifierSelective(entity);
 
         // Save extended information
-        this.updateExt(bid, businessInfo.getExtList());
+        this.updateExt(groupId, businessInfo.getExtList());
 
-        LOGGER.info("success to update business info");
-        return bid;
+        // Update the Pulsar info
+        if (BizConstant.MIDDLEWARE_PULSAR.equals(businessInfo.getMiddlewareType())) {
+            BusinessPulsarInfo pulsarInfo = (BusinessPulsarInfo) businessInfo.getMqExtInfo();
+            Preconditions.checkNotNull(pulsarInfo, "Pulsar info cannot be empty, as the middleware is Pulsar");
+            Integer writeQuorum = pulsarInfo.getWriteQuorum();
+            Integer ackQuorum = pulsarInfo.getAckQuorum();
+            if (!(ackQuorum <= writeQuorum)) {
+                throw new BusinessException(BizErrorCodeEnum.BUSINESS_SAVE_FAILED,
+                        "Pulsar params must meet: ackQuorum <= writeQuorum");
+            }
+            BusinessPulsarEntity pulsarEntity = CommonBeanUtils.copyProperties(pulsarInfo, BusinessPulsarEntity::new);
+            pulsarEntity.setInlongGroupId(groupId);
+            businessPulsarMapper.updateByIdentifierSelective(pulsarEntity);
+        }
+
+        LOGGER.info("success to update business info for groupId={}", groupId);
+        return groupId;
     }
 
     /**
@@ -191,19 +261,19 @@ public class BusinessServiceImpl implements BusinessService {
             throw new BusinessException(BizErrorCodeEnum.BUSINESS_UPDATE_NOT_ALLOWED);
         }
 
-        // Non-[DRAFT] status, no bid modification allowed
-        boolean updateBid = !EntityStatus.DRAFT.getCode().equals(oldStatus)
-                && !Objects.equals(entity.getBusinessIdentifier(), businessInfo.getBusinessIdentifier());
-        if (updateBid) {
-            LOGGER.error("current status was not allowed to update business identifier");
-            throw new BusinessException(BizErrorCodeEnum.BUSINESS_BID_UPDATE_NOT_ALLOWED);
+        // Non-[DRAFT] status, no groupId modification allowed
+        boolean updateGroupId = !EntityStatus.DRAFT.getCode().equals(oldStatus)
+                && !Objects.equals(entity.getInlongGroupId(), businessInfo.getInlongGroupId());
+        if (updateGroupId) {
+            LOGGER.error("current status was not allowed to update business group id");
+            throw new BusinessException(BizErrorCodeEnum.BUSINESS_GROUP_ID_UPDATE_NOT_ALLOWED);
         }
 
-        // [Configuration successful] Status, bid and middleware type are not allowed to be modified
+        // [Configuration successful] Status, groupId and middleware type are not allowed to be modified
         if (EntityStatus.BIZ_CONFIG_SUCCESSFUL.getCode().equals(oldStatus)) {
-            if (!Objects.equals(entity.getBusinessIdentifier(), businessInfo.getBusinessIdentifier())) {
-                LOGGER.error("current status was not allowed to update business identifier");
-                throw new BusinessException(BizErrorCodeEnum.BUSINESS_BID_UPDATE_NOT_ALLOWED);
+            if (!Objects.equals(entity.getInlongGroupId(), businessInfo.getInlongGroupId())) {
+                LOGGER.error("current status was not allowed to update business group id");
+                throw new BusinessException(BizErrorCodeEnum.BUSINESS_GROUP_ID_UPDATE_NOT_ALLOWED);
             }
             if (!Objects.equals(entity.getMiddlewareType(), businessInfo.getMiddlewareType())) {
                 LOGGER.error("current status was not allowed to update middleware type");
@@ -213,25 +283,25 @@ public class BusinessServiceImpl implements BusinessService {
     }
 
     @Override
-    public boolean updateStatus(String bid, Integer status, String operator) {
-        LOGGER.debug("begin to update business status, bid={}, status={}, username={}", bid, status, operator);
-        Preconditions.checkNotNull(bid, BizConstant.BID_IS_EMPTY);
+    public boolean updateStatus(String groupId, Integer status, String operator) {
+        LOGGER.debug("begin to update business status, groupId={}, status={}, username={}", groupId, status, operator);
+        Preconditions.checkNotNull(groupId, BizConstant.GROUP_ID_IS_EMPTY);
 
-        businessMapper.updateStatusByIdentifier(bid, status, operator);
+        businessMapper.updateStatusByIdentifier(groupId, status, operator);
 
-        LOGGER.info("success to update business status");
+        LOGGER.info("success to update business status for groupId={}", groupId);
         return true;
     }
 
     @Transactional(rollbackFor = Throwable.class)
     @Override
-    public boolean delete(String bid, String operator) {
-        LOGGER.debug("begin to delete business, bid={}", bid);
-        Preconditions.checkNotNull(bid, BizConstant.BID_IS_EMPTY);
+    public boolean delete(String groupId, String operator) {
+        LOGGER.debug("begin to delete business, groupId={}", groupId);
+        Preconditions.checkNotNull(groupId, BizConstant.GROUP_ID_IS_EMPTY);
 
-        BusinessEntity entity = businessMapper.selectByIdentifier(bid);
+        BusinessEntity entity = businessMapper.selectByIdentifier(groupId);
         if (entity == null) {
-            LOGGER.error("business not found by bid={}", bid);
+            LOGGER.error("business not found by groupId={}", groupId);
             throw new BusinessException(BizErrorCodeEnum.BUSINESS_NOT_FOUND);
         }
 
@@ -244,14 +314,14 @@ public class BusinessServiceImpl implements BusinessService {
         // [DRAFT] [BIZ_WAIT_SUBMIT] status, all associated data can be logically deleted directly
         if (EntityStatus.ALLOW_DELETE_BIZ_CASCADE_STATUS.contains(entity.getStatus())) {
             // Logically delete data streams, data sources and data storage information
-            streamService.logicDeleteAllByBid(entity.getBusinessIdentifier(), operator);
+            streamService.logicDeleteAll(entity.getInlongGroupId(), operator);
         } else {
             // In other states, you need to delete the associated "data stream" first.
             // When deleting a data stream, you also need to check whether there are
             // some associated "data source" and "data storage"
-            int count = streamService.selectCountByBid(bid);
+            int count = streamService.selectCountByGroupId(groupId);
             if (count >= 1) {
-                LOGGER.error("bid={} have [{}] data streams, deleted failed", bid, count);
+                LOGGER.error("groupId={} have [{}] data streams, deleted failed", groupId, count);
                 throw new BusinessException(BizErrorCodeEnum.BUSINESS_HAS_DATA_STREAM);
             }
         }
@@ -262,19 +332,21 @@ public class BusinessServiceImpl implements BusinessService {
         businessMapper.updateByIdentifierSelective(entity);
 
         // To logically delete the associated extension table
-        LOGGER.debug("begin to delete business ext property, bid={}", bid);
-        businessExtMapper.logicDeleteAllByBid(bid);
+        businessExtMapper.logicDeleteAllByGroupId(groupId);
 
-        LOGGER.info("success to delete business and business ext property");
+        // To logically delete the associated pulsar table
+        businessPulsarMapper.logicDeleteByGroupId(groupId);
+
+        LOGGER.info("success to delete business and business ext property for groupId={}", groupId);
         return true;
     }
 
     @Override
-    public boolean exist(String bid) {
-        LOGGER.debug("begin to check business, bid={}", bid);
-        Preconditions.checkNotNull(bid, BizConstant.BID_IS_EMPTY);
+    public boolean exist(String groupId) {
+        LOGGER.debug("begin to check business, groupId={}", groupId);
+        Preconditions.checkNotNull(groupId, BizConstant.GROUP_ID_IS_EMPTY);
 
-        Integer count = businessMapper.selectIdentifierExist(bid);
+        Integer count = businessMapper.selectIdentifierExist(groupId);
         LOGGER.info("success to check business");
         return count >= 1;
     }
@@ -297,28 +369,33 @@ public class BusinessServiceImpl implements BusinessService {
                 countVO.setRejectCount(countVO.getRejectCount() + count);
             }
         }
-        LOGGER.info("success to count business");
+        LOGGER.info("success to count business for operator={}", operator);
         return countVO;
     }
 
     @Override
-    public BusinessTopicVO getTopic(String bid) {
-        LOGGER.debug("begin to get topic by bid={}", bid);
-        BusinessInfo businessInfo = this.get(bid);
+    public BusinessTopicVO getTopic(String groupId) {
+        LOGGER.debug("begin to get topic by groupId={}", groupId);
+        BusinessInfo businessInfo = this.get(groupId);
 
         String middlewareType = businessInfo.getMiddlewareType();
         BusinessTopicVO topicVO = new BusinessTopicVO();
 
-        if (BizConstant.MIDDLEWARE_TYPE_TUBE.equalsIgnoreCase(middlewareType)) {
+        if (BizConstant.MIDDLEWARE_TUBE.equalsIgnoreCase(middlewareType)) {
             // Tube Topic corresponds to business one-to-one
-            topicVO.setTopicName(businessInfo.getMqResourceObj());
-            topicVO.setMasterUrl(clusterBean.getTubeMaster());
+            topicVO.setMqResourceObj(businessInfo.getMqResourceObj());
+            topicVO.setTubeMasterUrl(clusterBean.getTubeMaster());
+        } else if (BizConstant.MIDDLEWARE_PULSAR.equalsIgnoreCase(middlewareType)) {
+            // Pulsar's topic corresponds to the data stream one-to-one
+            topicVO.setDsTopicList(streamService.getTopicList(groupId));
+            topicVO.setPulsarAdminUrl(clusterBean.getPulsarAdminUrl());
+            topicVO.setPulsarServiceUrl(clusterBean.getPulsarServiceUrl());
         } else {
-            LOGGER.error("middlewareType={} not supported", middlewareType);
+            LOGGER.error("middleware type={} not supported", middlewareType);
             throw new BusinessException(BizErrorCodeEnum.MIDDLEWARE_TYPE_NOT_SUPPORTED);
         }
 
-        topicVO.setBusinessIdentifier(bid);
+        topicVO.setInlongGroupId(groupId);
         topicVO.setMiddlewareType(middlewareType);
         return topicVO;
     }
@@ -330,14 +407,16 @@ public class BusinessServiceImpl implements BusinessService {
 
         // Save the dataSchema, Topic and other information of the business
         Preconditions.checkNotNull(approveInfo, "BusinessApproveInfo is empty");
-        String bid = approveInfo.getBusinessIdentifier();
-        Preconditions.checkNotNull(bid, BizConstant.BID_IS_EMPTY);
+        String groupId = approveInfo.getInlongGroupId();
+        Preconditions.checkNotNull(groupId, BizConstant.GROUP_ID_IS_EMPTY);
+        String middlewareType = approveInfo.getMiddlewareType();
+        Preconditions.checkNotNull(middlewareType, "Middleware type is empty");
 
         // Update status to [BIZ_CONFIG_ING]
         // If you need to change business info after approve, just do in here
-        this.updateStatus(bid, EntityStatus.BIZ_CONFIG_ING.getCode(), operator);
+        this.updateStatus(groupId, EntityStatus.BIZ_CONFIG_ING.getCode(), operator);
 
-        LOGGER.info("success to update business status after approve");
+        LOGGER.info("success to update business status after approve for groupId={}", groupId);
         return true;
     }
 
@@ -346,11 +425,11 @@ public class BusinessServiceImpl implements BusinessService {
      * <p/>First physically delete the existing extended information, and then add this batch of extended information
      */
     @Transactional(rollbackFor = Throwable.class)
-    void updateExt(String bid, List<BusinessExtInfo> extInfoList) {
-        LOGGER.debug("begin to update business ext, bid={}, ext={}", bid, extInfoList);
+    void updateExt(String groupId, List<BusinessExtInfo> extInfoList) {
+        LOGGER.debug("begin to update business ext, groupId={}, ext={}", groupId, extInfoList);
         try {
-            businessExtMapper.deleteAllByBid(bid);
-            saveExt(bid, extInfoList);
+            businessExtMapper.deleteAllByGroupId(groupId);
+            saveExt(groupId, extInfoList);
             LOGGER.info("success to update business ext");
         } catch (Exception e) {
             LOGGER.error("failed to update business ext: ", e);
@@ -359,14 +438,14 @@ public class BusinessServiceImpl implements BusinessService {
     }
 
     @Transactional(rollbackFor = Throwable.class)
-    void saveExt(String bid, List<BusinessExtInfo> infoList) {
+    void saveExt(String groupId, List<BusinessExtInfo> infoList) {
         if (CollectionUtils.isEmpty(infoList)) {
             return;
         }
         List<BusinessExtEntity> entityList = CommonBeanUtils.copyListProperties(infoList, BusinessExtEntity::new);
         Date date = new Date();
         for (BusinessExtEntity entity : entityList) {
-            entity.setBusinessIdentifier(bid);
+            entity.setInlongGroupId(groupId);
             entity.setModifyTime(date);
         }
         businessExtMapper.insertAll(entityList);
