@@ -21,6 +21,7 @@ import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Map;
 import java.util.Set;
+import java.util.TreeSet;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.atomic.AtomicBoolean;
 import org.apache.inlong.tubemq.corebase.TokenConstants;
@@ -64,6 +65,19 @@ public class ClientSubInfo {
         return this.topicCondRegistry.get(topic);
     }
 
+    public void storeConsumeTarget(Map<String, TreeSet<String>> consumeTarget) {
+        TopicProcessor topicProcessor;
+        for (Map.Entry<String, TreeSet<String>> entry : consumeTarget.entrySet()) {
+            topicProcessor = new TopicProcessor(null, entry.getValue());
+            this.topicCondRegistry.put(entry.getKey(), topicProcessor);
+            this.subscribedTopics.add(entry.getKey());
+            this.topicFilterMap.put(entry.getKey(),
+                    (!(entry.getValue() == null || entry.getValue().isEmpty())));
+        }
+        this.requireBound = false;
+        this.subscribedTime = System.currentTimeMillis();
+    }
+
     public TopicProcessor putIfAbsentTopicProcessor(String topic,
                                                     TopicProcessor topicProcessor) {
         TopicProcessor topicProcessor1 =
@@ -125,6 +139,15 @@ public class ClientSubInfo {
         this.subscribedTime = System.currentTimeMillis();
     }
 
+    /**
+     * Set Bound Consumption information
+     *
+     * @param sessionKey     consume session key
+     * @param sourceCount    the client count of consume group
+     * @param isSelectBig    whether select a bigger data If there is reset conflict
+     * @param partOffsetMap  the map of partitionKey and bootstrap offset
+     *
+     */
     public void setRequireBound(final String sessionKey,
                                 final int sourceCount,
                                 final boolean isSelectBig,
