@@ -18,11 +18,15 @@
 package org.apache.inlong.tubemq.corebase.utils;
 
 import java.nio.ByteBuffer;
+import java.text.SimpleDateFormat;
+import java.util.ArrayList;
+import java.util.Date;
 import java.util.HashMap;
+import java.util.List;
 import java.util.Map;
 import java.util.TreeSet;
-
 import org.apache.commons.codec.binary.StringUtils;
+import org.apache.inlong.tubemq.corebase.Message;
 import org.apache.inlong.tubemq.corebase.TokenConstants;
 
 public class MixedUtils {
@@ -78,6 +82,25 @@ public class MixedUtils {
         return topicAndFiltersMap;
     }
 
+    // build the topic and filter item pair carried in the message
+    public static List<Tuple2<String, String>> buildTopicFilterTupleList(
+            Map<String, TreeSet<String>> topicAndFiltersMap) {
+        // initial send target
+        List<Tuple2<String, String>> topicFilterTuples = new ArrayList<>();
+        // initial topic send round
+        for (Map.Entry<String, TreeSet<String>> entry: topicAndFiltersMap.entrySet()) {
+            if (entry.getValue().isEmpty()) {
+                topicFilterTuples.add(new Tuple2<>(entry.getKey()));
+            } else {
+                for (String filter : entry.getValue()) {
+                    topicFilterTuples.add(new Tuple2<>(entry.getKey(), filter));
+                }
+            }
+        }
+        return topicFilterTuples;
+    }
+
+    // only for demo
     public static byte[] buildTestData(int bodySize) {
         final byte[] transmitData =
                 StringUtils.getBytesUtf8("This is a test data!");
@@ -91,6 +114,37 @@ public class MixedUtils {
         return dataBuffer.array();
     }
 
+    // build message to be sent
+    // only for demo
+    public static Message buildMessage(String topicName, String filterItem,
+                                       byte[] bodyData, long serialId,
+                                       SimpleDateFormat sdf) {
+        // build message to be sent
+        Message message = new Message(topicName, bodyData);
+        long currTimeMillis = System.currentTimeMillis();
+        // added a serial number and data generation time to each message
+        message.setAttrKeyVal("serialId", String.valueOf(serialId));
+        message.setAttrKeyVal("dataTime", String.valueOf(currTimeMillis));
+        if (filterItem != null) {
+            // add filter attribute information
+            message.putSystemHeader(filterItem, sdf.format(new Date(currTimeMillis)));
+        }
+        return message;
+    }
+
+    // only for demo
+    public static void coolSending(long msgSentCount) {
+        if (msgSentCount % 5000 == 0) {
+            ThreadUtils.sleep(3000);
+        } else if (msgSentCount % 4000 == 0) {
+            ThreadUtils.sleep(2000);
+        } else if (msgSentCount % 2000 == 0) {
+            ThreadUtils.sleep(800);
+        } else if (msgSentCount % 1000 == 0) {
+            ThreadUtils.sleep(400);
+        }
+    }
+
     // get the middle data between min, max, and data
     public static int mid(int data, int min, int max) {
         return Math.max(min, Math.min(max, data));
