@@ -35,6 +35,7 @@ import org.apache.inlong.tubemq.corebase.TErrCodeConstants;
 import org.apache.inlong.tubemq.corebase.protobuf.generated.ClientBroker;
 import org.apache.inlong.tubemq.corebase.utils.ServiceStatusHolder;
 import org.apache.inlong.tubemq.server.broker.BrokerConfig;
+import org.apache.inlong.tubemq.server.broker.metrics.BrokerMetricsHolder;
 import org.apache.inlong.tubemq.server.broker.msgstore.MessageStore;
 import org.apache.inlong.tubemq.server.broker.stats.CountItem;
 import org.apache.inlong.tubemq.server.broker.utils.DataStoreUtils;
@@ -115,7 +116,7 @@ public class MsgFileStore implements Closeable {
     public void batchAppendMsg(final StringBuilder sb, final int msgCnt,
                                final int indexSize, final ByteBuffer indexBuffer,
                                final int dataSize, final ByteBuffer dataBuffer) throws Throwable {
-        //　append message, put in data file first, then index file.
+        // append message, put in data file first, then index file.
         if (this.closed.get()) {
             throw new IllegalStateException(new StringBuilder(512)
                 .append("Closed MessageStore for storeKey ")
@@ -196,6 +197,7 @@ public class MsgFileStore implements Closeable {
             // print abnormal information
             if (inIndexOffset != indexOffset || inDataOffset != dataOffset) {
                 ServiceStatusHolder.addWriteIOErrCnt();
+                BrokerMetricsHolder.incIOExceptionCnt();
                 logger.error(sb.append("[File Store]: appendMsg data Error, storekey=")
                     .append(this.storeKey).append(",msgCnt=").append(msgCnt)
                     .append(",indexSize=").append(indexSize)
@@ -209,6 +211,7 @@ public class MsgFileStore implements Closeable {
         } catch (Throwable e) {
             if (!closed.get()) {
                 ServiceStatusHolder.addWriteIOErrCnt();
+                BrokerMetricsHolder.incIOExceptionCnt();
             }
             samplePrintCtrl.printExceptionCaught(e);
         } finally {
@@ -236,7 +239,7 @@ public class MsgFileStore implements Closeable {
                                         final String statisKeyBase,
                                         final int maxMsgTransferSize) {
         // #lizard forgives
-        //　Orderly read from index file, then random read from data file.
+        // Orderly read from index file, then random read from data file.
         int retCode = 0;
         int totalSize = 0;
         String errInfo = "Ok";
@@ -324,6 +327,7 @@ public class MsgFileStore implements Closeable {
             } catch (Throwable e2) {
                 if (e2 instanceof IOException) {
                     ServiceStatusHolder.addReadIOErrCnt();
+                    BrokerMetricsHolder.incIOExceptionCnt();
                 }
                 samplePrintCtrl.printExceptionCaught(e2,
                     messageStore.getStoreKey(), String.valueOf(partitionId));
@@ -574,7 +578,7 @@ public class MsgFileStore implements Closeable {
     }
 
     private void validateSegments(final String segTypeStr, final List<Segment> segments) {
-        //　valid segments, continuous
+        // valid segments, continuous
         for (int i = 0; i < segments.size() - 1; i++) {
             final Segment curr = segments.get(i);
             final Segment next = segments.get(i + 1);
