@@ -31,6 +31,7 @@ import org.apache.inlong.tubemq.corebase.utils.TStringUtils;
 import org.apache.inlong.tubemq.corebase.utils.Tuple2;
 import org.apache.inlong.tubemq.corebase.utils.Tuple3;
 import org.apache.inlong.tubemq.server.broker.BrokerConfig;
+import org.apache.inlong.tubemq.server.broker.metrics.BrokerMetricsHolder;
 import org.apache.inlong.tubemq.server.broker.msgstore.MessageStore;
 import org.apache.inlong.tubemq.server.broker.utils.DataStoreUtils;
 import org.apache.inlong.tubemq.server.common.offsetstorage.OffsetStorage;
@@ -613,6 +614,7 @@ public class DefaultOffsetManager extends AbstractDaemonService implements Offse
     }
 
     private void commitCfmOffsets(boolean retryable) {
+        long startTime = System.currentTimeMillis();
         for (Map.Entry<String, ConcurrentHashMap<String, OffsetStorageInfo>> entry : cfmOffsetMap.entrySet()) {
             if (TStringUtils.isBlank(entry.getKey())
                     || entry.getValue() == null || entry.getValue().isEmpty()) {
@@ -620,6 +622,7 @@ public class DefaultOffsetManager extends AbstractDaemonService implements Offse
             }
             zkOffsetStorage.commitOffset(entry.getKey(), entry.getValue().values(), retryable);
         }
+        BrokerMetricsHolder.updSyncZKDurations(System.currentTimeMillis() - startTime);
     }
 
     /***
