@@ -26,7 +26,7 @@ import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.atomic.AtomicInteger;
 import org.apache.commons.collections.CollectionUtils;
 import org.apache.inlong.tubemq.corebase.balance.ConsumerEvent;
-import org.apache.inlong.tubemq.corebase.cluster.ConsumerInfo;
+import org.apache.inlong.tubemq.server.master.metrics.MasterMetricsHolder;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -55,7 +55,9 @@ public class ConsumerEventManager {
             eventList = new LinkedList<>();
             LinkedList<ConsumerEvent> tmptList =
                     disconnectEventMap.putIfAbsent(consumerId, eventList);
-            if (tmptList != null) {
+            if (tmptList == null) {
+                MasterMetricsHolder.incSvrBalDisConConsumerCnt();
+            } else {
                 eventList = tmptList;
             }
         }
@@ -72,7 +74,9 @@ public class ConsumerEventManager {
             eventList = new LinkedList<>();
             LinkedList<ConsumerEvent> tmptList =
                     connectEventMap.putIfAbsent(consumerId, eventList);
-            if (tmptList != null) {
+            if (tmptList == null) {
+                MasterMetricsHolder.incSvrBalConEventConsumerCnt();
+            } else {
                 eventList = tmptList;
             }
         }
@@ -90,7 +94,7 @@ public class ConsumerEventManager {
      */
     public ConsumerEvent peek(String consumerId) {
         String group =
-                consumerHolder.getGroup(consumerId);
+                consumerHolder.getGroupName(consumerId);
         if (group != null) {
             ConcurrentHashMap<String, LinkedList<ConsumerEvent>> currentEventMap =
                     hasDisconnectEvent(group)
@@ -119,9 +123,10 @@ public class ConsumerEventManager {
      */
     public ConsumerEvent removeFirst(String consumerId) {
         ConsumerEvent event = null;
-        String group = consumerHolder.getGroup(consumerId);
+        String group = consumerHolder.getGroupName(consumerId);
+        boolean selDisConnMap = hasDisconnectEvent(group);
         ConcurrentHashMap<String, LinkedList<ConsumerEvent>> currentEventMap =
-                hasDisconnectEvent(group) ? disconnectEventMap : connectEventMap;
+                selDisConnMap ? disconnectEventMap : connectEventMap;
         LinkedList<ConsumerEvent> eventList = currentEventMap.get(consumerId);
         if (eventList != null) {
             synchronized (eventList) {
@@ -129,6 +134,11 @@ public class ConsumerEventManager {
                     event = eventList.removeFirst();
                     if (eventList.isEmpty()) {
                         currentEventMap.remove(consumerId);
+                        if (selDisConnMap) {
+                            MasterMetricsHolder.decSvrBalDisConConsumerCnt();
+                        } else {
+                            MasterMetricsHolder.decSvrBalConEventConsumerCnt();
+                        }
                     }
                 }
             }
@@ -183,8 +193,15 @@ public class ConsumerEventManager {
     }
 
     public void removeAll(String consumerId) {
-        disconnectEventMap.remove(consumerId);
-        connectEventMap.remove(consumerId);
+        LinkedList<ConsumerEvent> eventInfos =
+                disconnectEventMap.remove(consumerId);
+        if (eventInfos != null) {
+            MasterMetricsHolder.decSvrBalDisConConsumerCnt();
+        }
+        eventInfos = connectEventMap.remove(consumerId);
+        if (eventInfos != null) {
+            MasterMetricsHolder.decSvrBalConEventConsumerCnt();
+        }
     }
 
     /**
@@ -211,16 +228,19 @@ public class ConsumerEventManager {
     /**
      * Check if disconnect event map have event
      *
-     * @param group
+     * @param group    the group name needs a query
      * @return true if disconnect event map not empty otherwise false
      */
     public boolean hasDisconnectEvent(String group) {
-        List<ConsumerInfo> consumerList =
-                consumerHolder.getConsumerList(group);
-        if (CollectionUtils.isNotEmpty(consumerList)) {
-            for (ConsumerInfo consumer : consumerList) {
+        List<String> consumerIdList =
+                consumerHolder.getConsumerIdList(group);
+        if (CollectionUtils.isNotEmpty(consumerIdList)) {
+            for (String consumerId : consumerIdList) {
+                if (consumerId == null) {
+                    continue;
+                }
                 List<ConsumerEvent> eventList =
-                        disconnectEventMap.get(consumer.getConsumerId());
+                        disconnectEventMap.get(consumerId);
                 if (eventList != null) {
                     synchronized (eventList) {
                         if (CollectionUtils.isNotEmpty(eventList)) {
