@@ -20,6 +20,7 @@ package org.apache.inlong.tubemq.server.master.nodemanage.nodeproducer;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 import org.apache.inlong.tubemq.corebase.cluster.ProducerInfo;
+import org.apache.inlong.tubemq.server.master.metrics.MasterMetricsHolder;
 
 public class ProducerInfoHolder {
 
@@ -31,10 +32,12 @@ public class ProducerInfoHolder {
     }
 
     public void setProducerInfo(String producerId,
-                                Set<String> topicSet,
-                                String host, boolean overTLS) {
-        producerInfoMap.put(producerId,
-                new ProducerInfo(producerId, topicSet, host, overTLS));
+                                        Set<String> topicSet,
+                                        String host, boolean overTLS) {
+        if (producerInfoMap.put(producerId,
+                new ProducerInfo(producerId, topicSet, host, overTLS)) == null) {
+            MasterMetricsHolder.incProducerCnt();
+        }
     }
 
     public void updateProducerInfo(String producerId,
@@ -50,8 +53,12 @@ public class ProducerInfoHolder {
         }
     }
 
-    public ProducerInfo removeProducer(String producerId) {
-        return producerInfoMap.remove(producerId);
+    public ProducerInfo removeProducer(String producerId, boolean isTimeout) {
+        ProducerInfo info = producerInfoMap.remove(producerId);
+        if (info != null) {
+            MasterMetricsHolder.decProducerCnt(isTimeout);
+        }
+        return info;
     }
 
     public void clear() {
