@@ -17,7 +17,7 @@
  * under the License.
  */
 
-import React, { useState } from 'react';
+import React from 'react';
 import ReactDom from 'react-dom';
 import { Button, Space, message } from 'antd';
 import FormGenerator, { useForm } from '@/components/FormGenerator';
@@ -33,8 +33,6 @@ const Comp: React.FC<Props> = ({ id, isActive, readonly, extraRef }) => {
   const { t } = useTranslation();
   const [editing, { setTrue, setFalse }] = useBoolean(false);
 
-  const [changedValues, setChangedValues] = useState<Record<string, unknown>>({});
-
   const [form] = useForm();
 
   const { data, run: getDetail } = useRequest(
@@ -52,29 +50,17 @@ const Comp: React.FC<Props> = ({ id, isActive, readonly, extraRef }) => {
     },
   );
 
-  const { data: newBussinessData } = useRequest(
-    `/business/get/${changedValues.businessIdentifier}`,
-    {
-      refreshDeps: [changedValues.businessIdentifier],
-      ready: !!changedValues.businessIdentifier,
-      debounceInterval: 500,
-    },
-  );
-
-  const bussinessData =
-    editing && newBussinessData
-      ? newBussinessData
-      : {
-          middlewareType: data?.middlewareType,
-        };
-
   const onSave = async () => {
     const values = await form.validateFields();
     const submitData = {
       ...values,
       inCharges: values.inCharges.join(','),
       consumerGroupId: values.consumerGroupName,
-      middlewareType: bussinessData?.middlewareType || data?.middlewareType,
+      middlewareType: values?.middlewareType || data?.middlewareType,
+      mqExtInfo: {
+        ...values.mqExtInfo,
+        middlewareType: values.middlewareType,
+      },
     };
     await request({
       url: `/consumption/update/${id}`,
@@ -113,10 +99,8 @@ const Comp: React.FC<Props> = ({ id, isActive, readonly, extraRef }) => {
         content={getFormContent({
           editing,
           initialValues: data,
-          bussinessData,
         })}
         allValues={data}
-        onValuesChange={(c, v) => setChangedValues(v)}
         useMaxWidth={800}
       />
 
